==> jboss-modules_1.4.4.orig.tar.gz: jboss-modules-1.4.4.Final/src/main/java/org/jboss/modules/management/ResourceLoaderInfo.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014 Red Hat, Inc., and individual contributors
 * as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.modules.management;

import java.beans.ConstructorProperties;
import java.util.List;

/**
 * Information about a resource loader.
 *
 * @author <a href="mailto:david.lloyd@redhat.com">David M. Lloyd</a>
 */
public final class ResourceLoaderInfo {
    private final String type;
    private final List<String> paths;

    /**
     * Construct a new instance.
     *
     * @param type the type name
     * @param paths the paths list
     */
    @ConstructorProperties({"type", "paths"})
    public ResourceLoaderInfo(final String type, final List<String> paths) {
        this.type = type;
        this.paths = paths;
    }

    /**
     * Get the type name.
     *
     * @return the type name
     */
    public String getType() {
        return type;
    }

    /**
     * Get the paths list.
     *
     * @return the paths list
     */
    public List<String> getPaths() {
        return paths;
    }
}

==> jboss-modules_2.1.6.orig.tar.gz: jboss-modules-2.1.6.Final/src/main/java/org/jboss/modules/management/ResourceLoaderInfo.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014 Red Hat, Inc., and individual contributors
 * as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.modules.management;

import java.beans.ConstructorProperties;
import java.util.List;

/**
 * Information about a resource loader.
 *
 * @author <a href="mailto:david.lloyd@redhat.com">David M. Lloyd</a>
 */
public final class ResourceLoaderInfo {
    private final String type;
    private final String location;
    private final List<String> paths;

    /**
     * Construct a new instance.
     *
     * @param type the type name
     * @param location the physical location of the resource loader (if any)
     * @param paths the paths list
     */
    @ConstructorProperties({"type", "location", "paths"})
    public ResourceLoaderInfo(final String type, final String location, final List<String> paths) {
        this.type = type;
        this.location = location;
        this.paths = paths;
    }

    /**
     * Get the type name.
     *
     * @return the type name
     */
    public String getType() {
        return type;
    }

    /**
     * Get the resource loader location.
     *
     * @return the resource loader location
     */
    public String getLocation() {
        return location;
    }

    /**
     * Get the paths list.
     *
     * @return the paths list
     */
    public List<String> getPaths() {
        return paths;
    }
}
